pub enum DataType {
}Variants
Undetermined
Special variant not aimed to be explicitly used, it corresponds to the case a value Vec or Option didn’t contain any data, so is not determinable. It always matches other data type, including itself.
Void
I8
I16
I32
I64
I128
U8
U16
U32
U64
U128
F32
F64
Bool
Byte
Char
String
Vec(Box<DataType>)
Option(Box<DataType>)
Data(Data)
Implementations
Sourceimpl DataType
impl DataType
pub fn to_datatype(&self, collection: &Collection) -> Option<CommonDataType>